"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GET = void 0;
/**
 * @swagger
 * /store/auth/google/test:
 *   get:
 *     description: Test endpoint to verify Google OAuth2 configuration
 *     responses:
 *       200:
 *         description: Returns configuration information
 */
const GET = async (req, res) => {
    console.log("[GOOGLE AUTH] Test route called");
    try {
        const container = req.scope;
        if (!container) {
            throw new Error("Container not available in request");
        }
        const googleStrategy = container.resolve("googleOAuth2Strategy");
        if (!googleStrategy) {
            throw new Error("Google OAuth2 strategy not found");
        }
        const config = googleStrategy.getOAuth2Config();
        // Return configuration information
        return res.status(200).json({
            success: true,
            message: "Google Auth routes are properly registered",
            config: {
                callbackUrl: config.callbackURL,
                clientIdPrefix: config.clientID.substring(0, 8) + "..."
            }
        });
    }
    catch (error) {
        console.error("[GOOGLE AUTH] Error in test route:", error);
        return res.status(500).json({
            success: false,
            error: error.message
        });
    }
};
exports.GET = GET;
//# sourceMappingURL=route.js.map