"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_strategy_1 = require("./modules/auth/strategies/base-strategy");
const google_strategy_1 = require("./modules/auth/strategies/google-strategy");
const facebook_strategy_1 = require("./modules/auth/strategies/facebook-strategy");
const github_strategy_1 = require("./modules/auth/strategies/github-strategy");
const linkedin_strategy_1 = require("./modules/auth/strategies/linkedin-strategy");
const microsoft_strategy_1 = require("./modules/auth/strategies/microsoft-strategy");
const twitter_strategy_1 = require("./modules/auth/strategies/twitter-strategy");
const auth_service_1 = require("./modules/auth/core/services/auth.service");
const auth_utils_1 = require("./modules/auth/core/services/auth-utils");
const auth_strategies_1 = __importDefault(require("./loaders/auth-strategies"));
const base_subscriber_1 = __importDefault(require("./subscribers/base-subscriber"));
const auth_subscriber_1 = __importDefault(require("./subscribers/auth-subscriber"));
// A more reliable way to track initialization using a Symbol
const LOADED_MARKER = Symbol.for('medusa-plugin-auth-v2:loaded');
global[LOADED_MARKER] = global[LOADED_MARKER] || {
    initialized: false
};
/**
 * Medusa plugin for OAuth2 authentication
 * V2 compatible plugin definition
 */
exports.default = {
    // Plugin identification - required for Medusa v2
    name: "medusa-plugin-auth-v2",
    version: "2.0.0",
    // Register loaders - must come first to register strategies
    loaders: [
        // Wrapper to prevent duplicate registration
        async (container, options) => {
            const globalState = global[LOADED_MARKER];
            if (!globalState.initialized) {
                console.log("[AUTH PLUGIN] First initialization - registering strategies");
                globalState.initialized = true;
                return await (0, auth_strategies_1.default)(container, options);
            }
            else {
                console.log("[AUTH PLUGIN] Plugin already initialized - skipping strategy registration");
                return;
            }
        }
    ],
    // Register subscribers - using function-based subscribers
    subscribers: [
        base_subscriber_1.default,
        auth_subscriber_1.default
    ],
    // Re-export strategies for reference
    strategies: {
        base: base_strategy_1.BaseStrategy,
        google: google_strategy_1.GoogleOAuth2Strategy,
        facebook: facebook_strategy_1.FacebookOAuth2Strategy,
        github: github_strategy_1.GitHubOAuth2Strategy,
        linkedin: linkedin_strategy_1.LinkedInOAuth2Strategy,
        microsoft: microsoft_strategy_1.MicrosoftOAuth2Strategy,
        twitter: twitter_strategy_1.TwitterOAuth2Strategy
    },
    // Re-export services
    services: {
        authService: auth_service_1.AuthService
    },
    // Re-export utils
    utils: {
        authUtils: auth_utils_1.AuthUtils
    },
    // Required v2 keywords for plugin identification
    keywords: [
        "medusa-plugin",
        "medusa-v2",
        "auth",
        "oauth"
    ]
};
//# sourceMappingURL=index.js.map