"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthModule = void 0;
const auth_service_1 = require("./services/auth.service");
const passport_service_1 = require("./services/passport.service");
const auth_utils_1 = require("./services/auth-utils");
class AuthModule {
    constructor(container, options) {
        this.container = container;
        this.options = options;
    }
    async init() {
        // Initialize services
        const passportService = new passport_service_1.PassportService(this.container);
        const authUtils = new auth_utils_1.AuthUtils(this.container);
        const authService = new auth_service_1.AuthService(this.container);
        // Register services as resolvers
        this.container.register({
            passportService: {
                resolve: () => passportService
            },
            authService: {
                resolve: () => authService
            },
            authUtils: {
                resolve: () => authUtils
            }
        });
        // Skip registering the auth router - we're using explicit API routes instead
        // const authRouter = new AuthRouter(this.container)
        return {
            router: [
            // No router here to avoid conflicts with explicit API routes
            // {
            //   routes: authRouter.getRouter(),
            // },
            ],
            services: {
                passportService,
                authService,
                authUtils
            },
            loaders: {
                providers: this.options.providers
            }
        };
    }
}
exports.AuthModule = AuthModule;
exports.default = AuthModule;
//# sourceMappingURL=auth.module.js.map