"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PassportService = void 0;
class PassportService {
    constructor(container) {
        this.container = container;
        this.strategies = new Map();
    }
    registerStrategy(provider, strategy) {
        this.strategies.set(provider, strategy);
    }
    getStrategy(provider) {
        return this.strategies.get(provider);
    }
    authenticate(provider, data) {
        const strategy = this.getStrategy(provider);
        if (!strategy) {
            return Promise.reject(new Error(`Provider ${provider} is not supported`));
        }
        return new Promise((resolve, reject) => {
            strategy.authenticate(data)
                .then(result => resolve(result || {}))
                .catch(error => reject(error));
        });
    }
    async handleCallback(provider, data, authStrategy) {
        try {
            const result = await authStrategy.authenticate(data);
            if (!result) {
                throw new Error("Authentication failed");
            }
            const authResult = await authStrategy.afterAuth(result);
            if (!authResult) {
                throw new Error("After auth failed");
            }
            const successResult = await authStrategy.onSuccess(authResult);
            return successResult || {};
        }
        catch (error) {
            const errorData = {
                provider,
                error: error instanceof Error ? error : new Error("Unknown error"),
                ...data
            };
            const errorResult = await authStrategy.onError(errorData);
            return errorResult || {};
        }
    }
}
exports.PassportService = PassportService;
//# sourceMappingURL=passport.service.js.map