"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthService = void 0;
const medusa_1 = require("@medusajs/medusa");
const utils_1 = require("@medusajs/utils");
const auth_1 = require("../models/auth");
class AuthService extends medusa_1.TransactionBaseService {
    constructor({ manager, authRepository }) {
        super(arguments[0]);
        this.manager_ = manager;
        this.authRepository_ = authRepository;
    }
    async retrieve(selector, config) {
        var _a;
        const manager = (_a = this.transactionManager_) !== null && _a !== void 0 ? _a : this.manager_;
        const authRepo = manager.getRepository(auth_1.Auth);
        const query = (0, medusa_1.buildQuery)(selector, config);
        const auth = await authRepo.findOne(query);
        if (!auth) {
            throw new utils_1.MedusaError(utils_1.MedusaError.Types.NOT_FOUND, "Auth record not found");
        }
        return auth;
    }
    async create(data) {
        return await this.atomicPhase_(async (manager) => {
            const authRepo = manager.getRepository(auth_1.Auth);
            const auth = authRepo.create(data);
            return await authRepo.save(auth);
        });
    }
    async update(id, data) {
        return await this.atomicPhase_(async (manager) => {
            const authRepo = manager.getRepository(auth_1.Auth);
            const auth = await this.retrieve({ id });
            const updateData = {};
            for (const [key, value] of Object.entries(data)) {
                if (key in auth) {
                    switch (key) {
                        case 'provider':
                        case 'provider_id':
                            updateData[key] = value;
                            break;
                        case 'profile':
                        case 'metadata':
                            updateData[key] = value;
                            break;
                    }
                }
            }
            Object.assign(auth, updateData);
            return await authRepo.save(auth);
        });
    }
    async delete(id) {
        return await this.atomicPhase_(async (manager) => {
            const authRepo = manager.getRepository(auth_1.Auth);
            const auth = await this.retrieve({ id });
            await authRepo.remove(auth);
        });
    }
}
exports.AuthService = AuthService;
//# sourceMappingURL=auth.js.map