import { MedusaContainer } from "@medusajs/types";
import { Request } from "express";
import { AuthEventData } from "../types/workflow";
export interface BaseProfile {
    id: string;
    email: string;
    displayName: string;
    provider: string;
    picture?: string;
    locale?: string;
    verified?: boolean;
    metadata: Record<string, unknown>;
}
export interface AuthProfile extends BaseProfile {
    firstName: string;
    lastName: string;
}
export interface TransformedProfile extends BaseProfile {
    first_name: string;
    last_name: string;
}
export interface IAuthStrategy {
    validateCallback(accessToken: string, refreshToken: string, profile: any, done: (error: any, user?: any) => void): Promise<void>;
    authenticateRequest(req: Request): void;
    authenticate(reqOrData: Request | AuthEventData): Promise<Partial<AuthEventData>>;
    transformProfile(profile: AuthProfile): Promise<TransformedProfile>;
    afterAuth(data: AuthEventData): Promise<Partial<AuthEventData>>;
    onSuccess(data: AuthEventData): Promise<Partial<AuthEventData>>;
    onError(data: AuthEventData): Promise<Partial<AuthEventData>>;
}
export declare abstract class BaseStrategy implements IAuthStrategy {
    protected container: MedusaContainer;
    protected provider: string;
    protected config: Record<string, unknown>;
    constructor(container: MedusaContainer, provider: string, config: Record<string, unknown>);
    abstract validateCallback(accessToken: string, refreshToken: string, profile: any, done: (error: any, user?: any) => void): Promise<void>;
    abstract authenticateRequest(req: Request): void;
    abstract authenticate(reqOrData: Request | AuthEventData): Promise<Partial<AuthEventData>>;
    abstract transformProfile(profile: AuthProfile): Promise<TransformedProfile>;
    abstract afterAuth(data: AuthEventData): Promise<Partial<AuthEventData>>;
    abstract onSuccess(data: AuthEventData): Promise<Partial<AuthEventData>>;
    abstract onError(data: AuthEventData): Promise<Partial<AuthEventData>>;
    protected getConfig<T extends Record<string, unknown>>(): T;
    protected transformToAuthProfile(transformed: TransformedProfile): AuthProfile;
    protected transformToTransformedProfile(auth: AuthProfile): TransformedProfile;
}
