import { MedusaContainer } from "@medusajs/types";
import { OAuth2BaseStrategy, OAuth2Options } from "./oauth2-strategy";
import { AuthEventData } from "../types/workflow";
import { AuthProfile, TransformedProfile } from "./base-strategy";
import { Request } from "express";
import { Strategy as TwitterStrategy } from "passport-twitter";
export interface TwitterConfig extends OAuth2Options {
    consumerKey?: string;
    consumerSecret?: string;
}
type TwitterProfile = {
    id: string;
    displayName?: string;
    username?: string;
    name?: {
        familyName?: string;
        givenName?: string;
    };
    emails?: Array<{
        value: string;
    }>;
    photos?: Array<{
        value: string;
    }>;
    _json?: {
        profile_image_url_https?: string;
        email?: string;
    };
};
export declare class TwitterOAuth2Strategy extends OAuth2BaseStrategy {
    protected strategy: TwitterStrategy;
    private consumerKey;
    private consumerSecret;
    constructor(container: MedusaContainer, config: TwitterConfig);
    validateCallback(token: string, tokenSecret: string, profile: TwitterProfile, done: (error: any, user?: any) => void): Promise<void>;
    authenticateRequest(req: Request): void;
    transformProfile(profile: AuthProfile): Promise<TransformedProfile>;
    authenticate(reqOrData: Request | AuthEventData): Promise<Partial<AuthEventData>>;
    private isAuthEventData;
    afterAuth(data: AuthEventData): Promise<Partial<AuthEventData>>;
    onSuccess(data: AuthEventData): Promise<Partial<AuthEventData>>;
    onError(data: AuthEventData): Promise<Partial<AuthEventData>>;
}
export {};
