"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TwitterOAuth2Strategy = void 0;
const oauth2_strategy_1 = require("./oauth2-strategy");
const passport_twitter_1 = require("passport-twitter");
class TwitterOAuth2Strategy extends oauth2_strategy_1.OAuth2BaseStrategy {
    constructor(container, config) {
        super(container, "twitter", {
            clientID: config.clientID || config.consumerKey || "",
            clientSecret: config.clientSecret || config.consumerSecret || "",
            callbackURL: config.callbackURL
        });
        this.consumerKey = config.consumerKey || config.clientID || "";
        this.consumerSecret = config.consumerSecret || config.clientSecret || "";
        const strategyConfig = {
            consumerKey: this.consumerKey,
            consumerSecret: this.consumerSecret,
            callbackURL: this.getOAuth2Config().callbackURL,
            includeEmail: true,
            passReqToCallback: false
        };
        this.strategy = new passport_twitter_1.Strategy(strategyConfig, (token, tokenSecret, profile, done) => {
            this.validateCallback(token, tokenSecret, profile, done);
        });
    }
    async validateCallback(token, tokenSecret, profile, done) {
        var _a, _b, _c, _d, _e, _f;
        try {
            const transformedProfile = {
                id: profile.id,
                email: ((_b = (_a = profile.emails) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.value) || ((_c = profile._json) === null || _c === void 0 ? void 0 : _c.email) || "",
                first_name: ((_d = profile.name) === null || _d === void 0 ? void 0 : _d.givenName) || "",
                last_name: ((_e = profile.name) === null || _e === void 0 ? void 0 : _e.familyName) || "",
                displayName: profile.displayName || profile.username || "",
                provider: this.provider,
                metadata: {
                    raw: profile,
                    token,
                    tokenSecret,
                    profileImage: (_f = profile._json) === null || _f === void 0 ? void 0 : _f.profile_image_url_https,
                    username: profile.username
                }
            };
            const authProfile = this.transformToAuthProfile(transformedProfile);
            done(null, authProfile);
        }
        catch (error) {
            done(error);
        }
    }
    authenticateRequest(req) {
        this.strategy.authenticate(req);
    }
    async transformProfile(profile) {
        return {
            id: profile.id,
            email: profile.email,
            first_name: profile.firstName,
            last_name: profile.lastName,
            displayName: profile.displayName,
            provider: profile.provider,
            metadata: profile.metadata
        };
    }
    async authenticate(reqOrData) {
        if (reqOrData instanceof Request) {
            const query = reqOrData.query;
            const token = query === null || query === void 0 ? void 0 : query.oauth_token;
            const verifier = query === null || query === void 0 ? void 0 : query.oauth_verifier;
            if (!token || !verifier) {
                throw new Error("OAuth token and verifier are required");
            }
            return new Promise((resolve, reject) => {
                const handleResponse = (error, profile, info) => {
                    var _a, _b, _c, _d, _e, _f;
                    if (error) {
                        reject(error);
                        return;
                    }
                    if (!profile) {
                        reject(new Error("Failed to get Twitter profile"));
                        return;
                    }
                    this.transformProfile({
                        id: profile.id,
                        email: ((_b = (_a = profile.emails) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.value) || ((_c = profile._json) === null || _c === void 0 ? void 0 : _c.email) || "",
                        firstName: ((_d = profile.name) === null || _d === void 0 ? void 0 : _d.givenName) || "",
                        lastName: ((_e = profile.name) === null || _e === void 0 ? void 0 : _e.familyName) || "",
                        displayName: profile.displayName || profile.username || "",
                        provider: this.provider,
                        metadata: {
                            raw: profile,
                            token: info === null || info === void 0 ? void 0 : info.token,
                            tokenSecret: info === null || info === void 0 ? void 0 : info.tokenSecret,
                            profileImage: (_f = profile._json) === null || _f === void 0 ? void 0 : _f.profile_image_url_https,
                            username: profile.username
                        }
                    })
                        .then(transformedProfile => {
                        resolve({
                            provider: this.provider,
                            accessToken: info === null || info === void 0 ? void 0 : info.token,
                            profile: this.transformToAuthProfile(transformedProfile)
                        });
                    })
                        .catch(reject);
                };
                // Attach the callback to the request object
                const req = reqOrData;
                if (!req._passport) {
                    req._passport = { instance: { _strategy: () => this.strategy } };
                }
                // Call authenticate with the request object
                this.strategy.authenticate(req, handleResponse);
            });
        }
        // Handle direct AuthEventData
        if (!this.isAuthEventData(reqOrData)) {
            throw new Error("Invalid auth data format");
        }
        return reqOrData;
    }
    isAuthEventData(data) {
        return data && typeof data === 'object' && 'provider' in data;
    }
    async afterAuth(data) {
        return data;
    }
    async onSuccess(data) {
        return {
            ...data,
            metadata: {
                ...data.metadata,
                status: "success"
            }
        };
    }
    async onError(data) {
        return {
            ...data,
            metadata: {
                ...data.metadata,
                status: "error"
            }
        };
    }
}
exports.TwitterOAuth2Strategy = TwitterOAuth2Strategy;
//# sourceMappingURL=twitter-strategy.js.map