import { MedusaContainer } from "@medusajs/medusa";
import { AuthWorkflowData, AuthWorkflowOptions, AuthWorkflowResult } from "./types";
export declare const AUTH_WORKFLOW_ID = "auth";
declare enum AuthWorkflowSteps {
    INITIALIZE = "initialize",
    AUTHENTICATE = "authenticate",
    TRANSFORM_PROFILE = "transform_profile",
    CREATE_OR_UPDATE_USER = "create_or_update_user",
    FINALIZE = "finalize"
}
export declare class AuthWorkflow {
    protected readonly container: MedusaContainer;
    constructor(container: MedusaContainer);
    getId(): string;
    getSteps(): ({
        id: AuthWorkflowSteps;
        next: AuthWorkflowSteps[];
        handler: InitializeStepHandler;
    } | {
        id: AuthWorkflowSteps;
        next: AuthWorkflowSteps[];
        handler: AuthenticateStepHandler;
    } | {
        id: AuthWorkflowSteps;
        next: AuthWorkflowSteps[];
        handler: TransformProfileStepHandler;
    } | {
        id: AuthWorkflowSteps;
        next: AuthWorkflowSteps[];
        handler: CreateOrUpdateUserStepHandler;
    } | {
        id: AuthWorkflowSteps;
        next: any[];
        handler: FinalizeStepHandler;
    })[];
    run(data: AuthWorkflowData, options: AuthWorkflowOptions): Promise<AuthWorkflowResult>;
}
interface StepContext {
    options: AuthWorkflowOptions;
}
interface StepHandler {
    handle(data: AuthWorkflowData, context: StepContext): Promise<AuthWorkflowData | AuthWorkflowResult>;
}
declare class InitializeStepHandler implements StepHandler {
    protected readonly container: MedusaContainer;
    constructor(container: MedusaContainer);
    handle(data: AuthWorkflowData, context: StepContext): Promise<AuthWorkflowData>;
}
declare class AuthenticateStepHandler implements StepHandler {
    protected readonly container: MedusaContainer;
    constructor(container: MedusaContainer);
    handle(data: AuthWorkflowData, context: StepContext): Promise<AuthWorkflowData>;
}
declare class TransformProfileStepHandler implements StepHandler {
    protected readonly container: MedusaContainer;
    constructor(container: MedusaContainer);
    handle(data: AuthWorkflowData, context: StepContext): Promise<AuthWorkflowData>;
}
declare class CreateOrUpdateUserStepHandler implements StepHandler {
    protected readonly container: MedusaContainer;
    constructor(container: MedusaContainer);
    handle(data: AuthWorkflowData, context: StepContext): Promise<AuthWorkflowData>;
}
declare class FinalizeStepHandler implements StepHandler {
    protected readonly container: MedusaContainer;
    constructor(container: MedusaContainer);
    handle(data: AuthWorkflowData, _context: StepContext): Promise<AuthWorkflowResult>;
}
export {};
