"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthHook = void 0;
// Auth hook implementing Medusa v2 workflow pattern
class AuthHook {
    constructor(provider, strategy) {
        this.provider = provider;
        this.strategy = strategy;
    }
    async beforeAuth(data) {
        return {
            ...data,
            provider: this.provider,
            metadata: {
                ...data.metadata,
                status: "pending"
            }
        };
    }
    async authenticate(data) {
        try {
            return await this.strategy.authenticate(data);
        }
        catch (error) {
            return {
                ...data,
                error: error,
                metadata: {
                    ...data.metadata,
                    status: "error"
                }
            };
        }
    }
    async afterAuth(data) {
        try {
            return await this.strategy.afterAuth(data);
        }
        catch (error) {
            return {
                ...data,
                error: error,
                metadata: {
                    ...data.metadata,
                    status: "error"
                }
            };
        }
    }
    async onSuccess(data) {
        try {
            return await this.strategy.onSuccess(data);
        }
        catch (error) {
            return {
                ...data,
                error: error,
                metadata: {
                    ...data.metadata,
                    status: "error"
                }
            };
        }
    }
    async onError(data) {
        try {
            return await this.strategy.onError(data);
        }
        catch (error) {
            return {
                ...data,
                error: error,
                metadata: {
                    ...data.metadata,
                    status: "error"
                }
            };
        }
    }
}
exports.AuthHook = AuthHook;
//# sourceMappingURL=auth.hook.js.map