import { User } from "@medusajs/medusa";
export type SubscriberConfig = {
    event_names: string[];
    subscriber_config: {
        identifier: string;
    };
};
export declare const AuthEvents: {
    readonly AUTHENTICATED: "auth.authenticated";
    readonly AUTHENTICATION_ERROR: "auth.error";
    readonly USER_CREATED: "auth.user.created";
    readonly USER_UPDATED: "auth.user.updated";
    readonly PROFILE_TRANSFORMED: "auth.profile.transformed";
    readonly AUTH_FLOW_STARTED: "auth.flow.started";
    readonly AUTH_FLOW_COMPLETED: "auth.flow.completed";
    readonly AUTH_STRATEGY_RESOLVED: "auth.strategy.resolved";
    readonly AUTH_PROFILE_VALIDATED: "auth.profile.validated";
};
export type AuthEventData = {
    [AuthEvents.AUTHENTICATED]: {
        user: User;
        provider: string;
    };
    [AuthEvents.AUTHENTICATION_ERROR]: {
        error: Error;
        provider: string;
    };
    [AuthEvents.USER_CREATED]: {
        user: User;
        provider: string;
    };
    [AuthEvents.USER_UPDATED]: {
        user: User;
        provider: string;
    };
    [AuthEvents.PROFILE_TRANSFORMED]: {
        profile: Record<string, any>;
        transformedProfile: Record<string, any>;
        provider: string;
    };
    [AuthEvents.AUTH_FLOW_STARTED]: {
        provider: string;
        options: Record<string, any>;
    };
    [AuthEvents.AUTH_FLOW_COMPLETED]: {
        success: boolean;
        user?: User;
        error?: Error;
        provider: string;
    };
    [AuthEvents.AUTH_STRATEGY_RESOLVED]: {
        provider: string;
        strategyName: string;
    };
    [AuthEvents.AUTH_PROFILE_VALIDATED]: {
        profile: Record<string, any>;
        provider: string;
        valid: boolean;
        errors?: string[];
    };
};
export declare const config: SubscriberConfig;
type EventHandlerMap = {
    [key: string]: (data: any, eventName: string) => Promise<void>;
};
export default function authSubscriber({ eventBusService }: {
    eventBusService: any;
}): EventHandlerMap;
export {};
