"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.config = exports.AuthEvents = void 0;
exports.default = authSubscriber;
exports.AuthEvents = {
    AUTHENTICATED: "auth.authenticated",
    AUTHENTICATION_ERROR: "auth.error",
    USER_CREATED: "auth.user.created",
    USER_UPDATED: "auth.user.updated",
    PROFILE_TRANSFORMED: "auth.profile.transformed",
    AUTH_FLOW_STARTED: "auth.flow.started",
    AUTH_FLOW_COMPLETED: "auth.flow.completed",
    AUTH_STRATEGY_RESOLVED: "auth.strategy.resolved",
    AUTH_PROFILE_VALIDATED: "auth.profile.validated",
};
// Medusa v2 subscriber configuration
exports.config = {
    event_names: Object.values(exports.AuthEvents),
    subscriber_config: {
        identifier: "auth-subscriber"
    }
};
// Medusa v2 subscribers are functions, not classes
function authSubscriber({ eventBusService }) {
    async function handleAuthenticated(data, eventName) {
        const { user, provider } = data;
        console.log(`User ${user.email} authenticated successfully via ${provider}`);
    }
    async function handleAuthenticationError(data, eventName) {
        const { error, provider } = data;
        console.error(`Authentication error with provider ${provider}:`, error.message);
    }
    async function handleUserCreated(data, eventName) {
        const { user, provider } = data;
        console.log(`New user ${user.email} created via ${provider}`);
    }
    async function handleUserUpdated(data, eventName) {
        const { user, provider } = data;
        console.log(`User ${user.email} updated via ${provider}`);
    }
    async function handleProfileTransformed(data, eventName) {
        const { provider } = data;
        console.log(`Profile transformed for provider ${provider}`);
    }
    async function handleAuthFlowStarted(data, eventName) {
        const { provider, options } = data;
        console.log(`Authentication flow started for provider ${provider} with options:`, options);
    }
    async function handleAuthFlowCompleted(data, eventName) {
        const { success, user, error, provider } = data;
        if (success && user) {
            console.log(`Authentication flow completed successfully for user ${user.email} via ${provider}`);
        }
        else if (error) {
            console.error(`Authentication flow failed for provider ${provider}:`, error.message);
        }
    }
    async function handleAuthStrategyResolved(data, eventName) {
        const { provider, strategyName } = data;
        console.log(`Resolved auth strategy ${strategyName} for provider ${provider}`);
    }
    async function handleAuthProfileValidated(data, eventName) {
        const { provider, valid, errors } = data;
        if (valid) {
            console.log(`Profile validation successful for provider ${provider}`);
        }
        else {
            console.error(`Profile validation failed for provider ${provider}:`, errors);
        }
    }
    // Create handler map for Medusa v2
    const handlers = {
        [exports.AuthEvents.AUTHENTICATED]: handleAuthenticated,
        [exports.AuthEvents.AUTHENTICATION_ERROR]: handleAuthenticationError,
        [exports.AuthEvents.USER_CREATED]: handleUserCreated,
        [exports.AuthEvents.USER_UPDATED]: handleUserUpdated,
        [exports.AuthEvents.PROFILE_TRANSFORMED]: handleProfileTransformed,
        [exports.AuthEvents.AUTH_FLOW_STARTED]: handleAuthFlowStarted,
        [exports.AuthEvents.AUTH_FLOW_COMPLETED]: handleAuthFlowCompleted,
        [exports.AuthEvents.AUTH_STRATEGY_RESOLVED]: handleAuthStrategyResolved,
        [exports.AuthEvents.AUTH_PROFILE_VALIDATED]: handleAuthProfileValidated,
    };
    // Return handlers directly - each key matches an event name
    return handlers;
}
//# sourceMappingURL=auth-subscriber.js.map