"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.config = exports.BaseEvents = void 0;
exports.default = baseSubscriber;
// Define specific events this subscriber handles
exports.BaseEvents = {
    USER_CREATED: "user.created",
    USER_UPDATED: "user.updated",
    USER_DELETED: "user.deleted",
};
// Medusa v2 subscriber configuration
exports.config = {
    event_names: Object.values(exports.BaseEvents),
    subscriber_config: {
        identifier: "base-subscriber"
    }
};
// Medusa v2 subscribers are functions, not classes
function baseSubscriber({ eventBusService }) {
    // Individual event handlers
    async function handleUserCreated(data, eventName) {
        console.log(`User created: ${JSON.stringify(data.id)}`);
    }
    async function handleUserUpdated(data, eventName) {
        console.log(`User updated: ${JSON.stringify(data.id)}`);
    }
    async function handleUserDeleted(data, eventName) {
        console.log(`User deleted: ${JSON.stringify(data.id)}`);
    }
    // Create handler map for Medusa v2
    const handlers = {
        [exports.BaseEvents.USER_CREATED]: handleUserCreated,
        [exports.BaseEvents.USER_UPDATED]: handleUserUpdated,
        [exports.BaseEvents.USER_DELETED]: handleUserDeleted,
    };
    // Return handlers directly - each key matches an event name
    return handlers;
}
//# sourceMappingURL=base-subscriber.js.map